==> ovirt-engine-sdk-java-4.1.6.tar.gz: ovirt-engine-sdk-java-4.1.6/target/generated-sources/org/ovirt/engine/sdk4/types/HostStorage.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.types;

import java.lang.String;
import java.math.BigInteger;
import java.util.List;

public interface HostStorage extends Identified {
    String address();
    
    boolean addressPresent();
    
    List<LogicalUnit> logicalUnits();
    
    boolean logicalUnitsPresent();
    
    String mountOptions();
    
    boolean mountOptionsPresent();
    
    BigInteger nfsRetrans();
    
    boolean nfsRetransPresent();
    
    BigInteger nfsTimeo();
    
    boolean nfsTimeoPresent();
    
    NfsVersion nfsVersion();
    
    boolean nfsVersionPresent();
    
    boolean overrideLuns();
    
    boolean overrideLunsPresent();
    
    String password();
    
    boolean passwordPresent();
    
    String path();
    
    boolean pathPresent();
    
    BigInteger port();
    
    boolean portPresent();
    
    String portal();
    
    boolean portalPresent();
    
    String target();
    
    boolean targetPresent();
    
    StorageType type();
    
    boolean typePresent();
    
    String username();
    
    boolean usernamePresent();
    
    String vfsType();
    
    boolean vfsTypePresent();
    
    VolumeGroup volumeGroup();
    
    boolean volumeGroupPresent();
    
    Host host();
    
    boolean hostPresent();
    
}

==> ovirt-engine-sdk-java-4.4.5.tar.gz: ovirt-engine-sdk-java-4.4.5/target/generated-sources/org/ovirt/engine/sdk4/types/HostStorage.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.types;

import java.lang.String;
import java.math.BigInteger;
import java.util.List;

public interface HostStorage extends Identified {
    String address();
    
    boolean addressPresent();
    
    List<Property> driverOptions();
    
    boolean driverOptionsPresent();
    
    List<Property> driverSensitiveOptions();
    
    boolean driverSensitiveOptionsPresent();
    
    List<LogicalUnit> logicalUnits();
    
    boolean logicalUnitsPresent();
    
    String mountOptions();
    
    boolean mountOptionsPresent();
    
    BigInteger nfsRetrans();
    Byte nfsRetransAsByte();
    Short nfsRetransAsShort();
    Integer nfsRetransAsInteger();
    Long nfsRetransAsLong();
    
    boolean nfsRetransPresent();
    
    BigInteger nfsTimeo();
    Byte nfsTimeoAsByte();
    Short nfsTimeoAsShort();
    Integer nfsTimeoAsInteger();
    Long nfsTimeoAsLong();
    
    boolean nfsTimeoPresent();
    
    NfsVersion nfsVersion();
    
    boolean nfsVersionPresent();
    
    boolean overrideLuns();
    
    boolean overrideLunsPresent();
    
    String password();
    
    boolean passwordPresent();
    
    String path();
    
    boolean pathPresent();
    
    BigInteger port();
    Byte portAsByte();
    Short portAsShort();
    Integer portAsInteger();
    Long portAsLong();
    
    boolean portPresent();
    
    String portal();
    
    boolean portalPresent();
    
    String target();
    
    boolean targetPresent();
    
    StorageType type();
    
    boolean typePresent();
    
    String username();
    
    boolean usernamePresent();
    
    String vfsType();
    
    boolean vfsTypePresent();
    
    VolumeGroup volumeGroup();
    
    boolean volumeGroupPresent();
    
    Host host();
    
    boolean hostPresent();
    
}
